@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,6 +27,8 @@ from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import google.protobuf
+from google.protobuf import empty_pb2  # type: ignore
 
 from google.cloud.dataplex_v1 import gapic_version as package_version
 from google.cloud.dataplex_v1.types import catalog
@@ -35,6 +37,9 @@ DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     gapic_version=package_version.__version__
 )
 
+if hasattr(DEFAULT_CLIENT_INFO, "protobuf_runtime_version"):  # pragma: NO COVER
+    DEFAULT_CLIENT_INFO.protobuf_runtime_version = google.protobuf.__version__
+
 
 class CatalogServiceTransport(abc.ABC):
     """Abstract transport class for CatalogService."""
@@ -352,6 +357,26 @@ class CatalogServiceTransport(abc.ABC):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
+            self.create_metadata_job: gapic_v1.method.wrap_method(
+                self.create_metadata_job,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.get_metadata_job: gapic_v1.method.wrap_method(
+                self.get_metadata_job,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_metadata_jobs: gapic_v1.method.wrap_method(
+                self.list_metadata_jobs,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.cancel_metadata_job: gapic_v1.method.wrap_method(
+                self.cancel_metadata_job,
+                default_timeout=None,
+                client_info=client_info,
+            ),
             self.get_location: gapic_v1.method.wrap_method(
                 self.get_location,
                 default_timeout=None,
@@ -597,6 +622,45 @@ class CatalogServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def create_metadata_job(
+        self,
+    ) -> Callable[
+        [catalog.CreateMetadataJobRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def get_metadata_job(
+        self,
+    ) -> Callable[
+        [catalog.GetMetadataJobRequest],
+        Union[catalog.MetadataJob, Awaitable[catalog.MetadataJob]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def list_metadata_jobs(
+        self,
+    ) -> Callable[
+        [catalog.ListMetadataJobsRequest],
+        Union[
+            catalog.ListMetadataJobsResponse,
+            Awaitable[catalog.ListMetadataJobsResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def cancel_metadata_job(
+        self,
+    ) -> Callable[
+        [catalog.CancelMetadataJobRequest],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def list_operations(
         self,
