@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import json
+import logging as std_logging
+import pickle
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -24,21 +27,99 @@ from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf.json_format import MessageToJson
+import google.protobuf.message
 import grpc  # type: ignore
+import proto  # type: ignore
 
 from google.cloud.dataplex_v1.types import catalog
 
 from .base import DEFAULT_CLIENT_INFO, CatalogServiceTransport
 
+try:
+    from google.api_core import client_logging  # type: ignore
+
+    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
+    CLIENT_LOGGING_SUPPORTED = False
+
+_LOGGER = std_logging.getLogger(__name__)
+
+
+class _LoggingClientInterceptor(grpc.UnaryUnaryClientInterceptor):  # pragma: NO COVER
+    def intercept_unary_unary(self, continuation, client_call_details, request):
+        logging_enabled = CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+            std_logging.DEBUG
+        )
+        if logging_enabled:  # pragma: NO COVER
+            request_metadata = client_call_details.metadata
+            if isinstance(request, proto.Message):
+                request_payload = type(request).to_json(request)
+            elif isinstance(request, google.protobuf.message.Message):
+                request_payload = MessageToJson(request)
+            else:
+                request_payload = f"{type(request).__name__}: {pickle.dumps(request)}"
+
+            request_metadata = {
+                key: value.decode("utf-8") if isinstance(value, bytes) else value
+                for key, value in request_metadata
+            }
+            grpc_request = {
+                "payload": request_payload,
+                "requestMethod": "grpc",
+                "metadata": dict(request_metadata),
+            }
+            _LOGGER.debug(
+                f"Sending request for {client_call_details.method}",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.CatalogService",
+                    "rpcName": str(client_call_details.method),
+                    "request": grpc_request,
+                    "metadata": grpc_request["metadata"],
+                },
+            )
+        response = continuation(client_call_details, request)
+        if logging_enabled:  # pragma: NO COVER
+            response_metadata = response.trailing_metadata()
+            # Convert gRPC metadata `<class 'grpc.aio._metadata.Metadata'>` to list of tuples
+            metadata = (
+                dict([(k, str(v)) for k, v in response_metadata])
+                if response_metadata
+                else None
+            )
+            result = response.result()
+            if isinstance(result, proto.Message):
+                response_payload = type(result).to_json(result)
+            elif isinstance(result, google.protobuf.message.Message):
+                response_payload = MessageToJson(result)
+            else:
+                response_payload = f"{type(result).__name__}: {pickle.dumps(result)}"
+            grpc_response = {
+                "payload": response_payload,
+                "metadata": metadata,
+                "status": "OK",
+            }
+            _LOGGER.debug(
+                f"Received response for {client_call_details.method}.",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.CatalogService",
+                    "rpcName": client_call_details.method,
+                    "response": grpc_response,
+                    "metadata": grpc_response["metadata"],
+                },
+            )
+        return response
+
 
 class CatalogServiceGrpcTransport(CatalogServiceTransport):
     """gRPC backend transport for CatalogService.
 
     The primary resources offered by this service are
-    EntryGroups, EntryTypes, AspectTypes, Entry and Aspect which
-    collectively allow a data administrator to organize, manage,
-    secure and catalog data across their organization located across
-    cloud projects in a variety of storage systems including Cloud
+    EntryGroups, EntryTypes, AspectTypes, and Entries. They
+    collectively let data administrators organize, manage, secure,
+    and catalog data located across cloud projects in their
+    organization in a variety of storage systems, including Cloud
     Storage and BigQuery.
 
     This class defines the same methods as the primary client, so the
@@ -189,7 +270,12 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
                 ],
             )
 
-        # Wrap messages. This must be done after self._grpc_channel exists
+        self._interceptor = _LoggingClientInterceptor()
+        self._logged_channel = grpc.intercept_channel(
+            self._grpc_channel, self._interceptor
+        )
+
+        # Wrap messages. This must be done after self._logged_channel exists
         self._prep_wrapped_messages(client_info)
 
     @classmethod
@@ -253,7 +339,9 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         """
         # Quick check: Only create a new client if we do not already have one.
         if self._operations_client is None:
-            self._operations_client = operations_v1.OperationsClient(self.grpc_channel)
+            self._operations_client = operations_v1.OperationsClient(
+                self._logged_channel
+            )
 
         # Return the client from cache.
         return self._operations_client
@@ -264,7 +352,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.CreateEntryTypeRequest], operations_pb2.Operation]:
         r"""Return a callable for the create entry type method over gRPC.
 
-        Creates an EntryType
+        Creates an EntryType.
 
         Returns:
             Callable[[~.CreateEntryTypeRequest],
@@ -277,7 +365,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_entry_type" not in self._stubs:
-            self._stubs["create_entry_type"] = self.grpc_channel.unary_unary(
+            self._stubs["create_entry_type"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/CreateEntryType",
                 request_serializer=catalog.CreateEntryTypeRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -290,7 +378,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.UpdateEntryTypeRequest], operations_pb2.Operation]:
         r"""Return a callable for the update entry type method over gRPC.
 
-        Updates a EntryType resource.
+        Updates an EntryType.
 
         Returns:
             Callable[[~.UpdateEntryTypeRequest],
@@ -303,7 +391,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_entry_type" not in self._stubs:
-            self._stubs["update_entry_type"] = self.grpc_channel.unary_unary(
+            self._stubs["update_entry_type"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/UpdateEntryType",
                 request_serializer=catalog.UpdateEntryTypeRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -316,7 +404,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.DeleteEntryTypeRequest], operations_pb2.Operation]:
         r"""Return a callable for the delete entry type method over gRPC.
 
-        Deletes a EntryType resource.
+        Deletes an EntryType.
 
         Returns:
             Callable[[~.DeleteEntryTypeRequest],
@@ -329,7 +417,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_entry_type" not in self._stubs:
-            self._stubs["delete_entry_type"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_entry_type"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/DeleteEntryType",
                 request_serializer=catalog.DeleteEntryTypeRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -355,7 +443,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_entry_types" not in self._stubs:
-            self._stubs["list_entry_types"] = self.grpc_channel.unary_unary(
+            self._stubs["list_entry_types"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/ListEntryTypes",
                 request_serializer=catalog.ListEntryTypesRequest.serialize,
                 response_deserializer=catalog.ListEntryTypesResponse.deserialize,
@@ -368,7 +456,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.GetEntryTypeRequest], catalog.EntryType]:
         r"""Return a callable for the get entry type method over gRPC.
 
-        Retrieves a EntryType resource.
+        Gets an EntryType.
 
         Returns:
             Callable[[~.GetEntryTypeRequest],
@@ -381,7 +469,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_entry_type" not in self._stubs:
-            self._stubs["get_entry_type"] = self.grpc_channel.unary_unary(
+            self._stubs["get_entry_type"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/GetEntryType",
                 request_serializer=catalog.GetEntryTypeRequest.serialize,
                 response_deserializer=catalog.EntryType.deserialize,
@@ -394,7 +482,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.CreateAspectTypeRequest], operations_pb2.Operation]:
         r"""Return a callable for the create aspect type method over gRPC.
 
-        Creates an AspectType
+        Creates an AspectType.
 
         Returns:
             Callable[[~.CreateAspectTypeRequest],
@@ -407,7 +495,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_aspect_type" not in self._stubs:
-            self._stubs["create_aspect_type"] = self.grpc_channel.unary_unary(
+            self._stubs["create_aspect_type"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/CreateAspectType",
                 request_serializer=catalog.CreateAspectTypeRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -420,7 +508,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.UpdateAspectTypeRequest], operations_pb2.Operation]:
         r"""Return a callable for the update aspect type method over gRPC.
 
-        Updates a AspectType resource.
+        Updates an AspectType.
 
         Returns:
             Callable[[~.UpdateAspectTypeRequest],
@@ -433,7 +521,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_aspect_type" not in self._stubs:
-            self._stubs["update_aspect_type"] = self.grpc_channel.unary_unary(
+            self._stubs["update_aspect_type"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/UpdateAspectType",
                 request_serializer=catalog.UpdateAspectTypeRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -446,7 +534,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.DeleteAspectTypeRequest], operations_pb2.Operation]:
         r"""Return a callable for the delete aspect type method over gRPC.
 
-        Deletes a AspectType resource.
+        Deletes an AspectType.
 
         Returns:
             Callable[[~.DeleteAspectTypeRequest],
@@ -459,7 +547,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_aspect_type" not in self._stubs:
-            self._stubs["delete_aspect_type"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_aspect_type"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/DeleteAspectType",
                 request_serializer=catalog.DeleteAspectTypeRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -485,7 +573,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_aspect_types" not in self._stubs:
-            self._stubs["list_aspect_types"] = self.grpc_channel.unary_unary(
+            self._stubs["list_aspect_types"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/ListAspectTypes",
                 request_serializer=catalog.ListAspectTypesRequest.serialize,
                 response_deserializer=catalog.ListAspectTypesResponse.deserialize,
@@ -498,7 +586,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.GetAspectTypeRequest], catalog.AspectType]:
         r"""Return a callable for the get aspect type method over gRPC.
 
-        Retrieves a AspectType resource.
+        Gets an AspectType.
 
         Returns:
             Callable[[~.GetAspectTypeRequest],
@@ -511,7 +599,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_aspect_type" not in self._stubs:
-            self._stubs["get_aspect_type"] = self.grpc_channel.unary_unary(
+            self._stubs["get_aspect_type"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/GetAspectType",
                 request_serializer=catalog.GetAspectTypeRequest.serialize,
                 response_deserializer=catalog.AspectType.deserialize,
@@ -524,7 +612,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.CreateEntryGroupRequest], operations_pb2.Operation]:
         r"""Return a callable for the create entry group method over gRPC.
 
-        Creates an EntryGroup
+        Creates an EntryGroup.
 
         Returns:
             Callable[[~.CreateEntryGroupRequest],
@@ -537,7 +625,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_entry_group" not in self._stubs:
-            self._stubs["create_entry_group"] = self.grpc_channel.unary_unary(
+            self._stubs["create_entry_group"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/CreateEntryGroup",
                 request_serializer=catalog.CreateEntryGroupRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -550,7 +638,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.UpdateEntryGroupRequest], operations_pb2.Operation]:
         r"""Return a callable for the update entry group method over gRPC.
 
-        Updates a EntryGroup resource.
+        Updates an EntryGroup.
 
         Returns:
             Callable[[~.UpdateEntryGroupRequest],
@@ -563,7 +651,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_entry_group" not in self._stubs:
-            self._stubs["update_entry_group"] = self.grpc_channel.unary_unary(
+            self._stubs["update_entry_group"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/UpdateEntryGroup",
                 request_serializer=catalog.UpdateEntryGroupRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -576,7 +664,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.DeleteEntryGroupRequest], operations_pb2.Operation]:
         r"""Return a callable for the delete entry group method over gRPC.
 
-        Deletes a EntryGroup resource.
+        Deletes an EntryGroup.
 
         Returns:
             Callable[[~.DeleteEntryGroupRequest],
@@ -589,7 +677,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_entry_group" not in self._stubs:
-            self._stubs["delete_entry_group"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_entry_group"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/DeleteEntryGroup",
                 request_serializer=catalog.DeleteEntryGroupRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -615,7 +703,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_entry_groups" not in self._stubs:
-            self._stubs["list_entry_groups"] = self.grpc_channel.unary_unary(
+            self._stubs["list_entry_groups"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/ListEntryGroups",
                 request_serializer=catalog.ListEntryGroupsRequest.serialize,
                 response_deserializer=catalog.ListEntryGroupsResponse.deserialize,
@@ -628,7 +716,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.GetEntryGroupRequest], catalog.EntryGroup]:
         r"""Return a callable for the get entry group method over gRPC.
 
-        Retrieves a EntryGroup resource.
+        Gets an EntryGroup.
 
         Returns:
             Callable[[~.GetEntryGroupRequest],
@@ -641,7 +729,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_entry_group" not in self._stubs:
-            self._stubs["get_entry_group"] = self.grpc_channel.unary_unary(
+            self._stubs["get_entry_group"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/GetEntryGroup",
                 request_serializer=catalog.GetEntryGroupRequest.serialize,
                 response_deserializer=catalog.EntryGroup.deserialize,
@@ -665,7 +753,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_entry" not in self._stubs:
-            self._stubs["create_entry"] = self.grpc_channel.unary_unary(
+            self._stubs["create_entry"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/CreateEntry",
                 request_serializer=catalog.CreateEntryRequest.serialize,
                 response_deserializer=catalog.Entry.deserialize,
@@ -689,7 +777,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_entry" not in self._stubs:
-            self._stubs["update_entry"] = self.grpc_channel.unary_unary(
+            self._stubs["update_entry"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/UpdateEntry",
                 request_serializer=catalog.UpdateEntryRequest.serialize,
                 response_deserializer=catalog.Entry.deserialize,
@@ -713,7 +801,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_entry" not in self._stubs:
-            self._stubs["delete_entry"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_entry"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/DeleteEntry",
                 request_serializer=catalog.DeleteEntryRequest.serialize,
                 response_deserializer=catalog.Entry.deserialize,
@@ -726,7 +814,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.ListEntriesRequest], catalog.ListEntriesResponse]:
         r"""Return a callable for the list entries method over gRPC.
 
-        Lists entries within an entry group.
+        Lists Entries within an EntryGroup.
 
         Returns:
             Callable[[~.ListEntriesRequest],
@@ -739,7 +827,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_entries" not in self._stubs:
-            self._stubs["list_entries"] = self.grpc_channel.unary_unary(
+            self._stubs["list_entries"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/ListEntries",
                 request_serializer=catalog.ListEntriesRequest.serialize,
                 response_deserializer=catalog.ListEntriesResponse.deserialize,
@@ -750,7 +838,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     def get_entry(self) -> Callable[[catalog.GetEntryRequest], catalog.Entry]:
         r"""Return a callable for the get entry method over gRPC.
 
-        Gets a single entry.
+        Gets an Entry.
 
         Returns:
             Callable[[~.GetEntryRequest],
@@ -763,7 +851,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_entry" not in self._stubs:
-            self._stubs["get_entry"] = self.grpc_channel.unary_unary(
+            self._stubs["get_entry"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/GetEntry",
                 request_serializer=catalog.GetEntryRequest.serialize,
                 response_deserializer=catalog.Entry.deserialize,
@@ -774,7 +862,8 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     def lookup_entry(self) -> Callable[[catalog.LookupEntryRequest], catalog.Entry]:
         r"""Return a callable for the lookup entry method over gRPC.
 
-        Looks up a single entry.
+        Looks up an entry by name using the permission on the
+        source system.
 
         Returns:
             Callable[[~.LookupEntryRequest],
@@ -787,7 +876,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "lookup_entry" not in self._stubs:
-            self._stubs["lookup_entry"] = self.grpc_channel.unary_unary(
+            self._stubs["lookup_entry"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/LookupEntry",
                 request_serializer=catalog.LookupEntryRequest.serialize,
                 response_deserializer=catalog.Entry.deserialize,
@@ -800,7 +889,8 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
     ) -> Callable[[catalog.SearchEntriesRequest], catalog.SearchEntriesResponse]:
         r"""Return a callable for the search entries method over gRPC.
 
-        Searches for entries matching given query and scope.
+        Searches for Entries matching the given query and
+        scope.
 
         Returns:
             Callable[[~.SearchEntriesRequest],
@@ -813,15 +903,127 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "search_entries" not in self._stubs:
-            self._stubs["search_entries"] = self.grpc_channel.unary_unary(
+            self._stubs["search_entries"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.CatalogService/SearchEntries",
                 request_serializer=catalog.SearchEntriesRequest.serialize,
                 response_deserializer=catalog.SearchEntriesResponse.deserialize,
             )
         return self._stubs["search_entries"]
 
+    @property
+    def create_metadata_job(
+        self,
+    ) -> Callable[[catalog.CreateMetadataJobRequest], operations_pb2.Operation]:
+        r"""Return a callable for the create metadata job method over gRPC.
+
+        Creates a metadata job. For example, use a metadata
+        job to import Dataplex Catalog entries and aspects from
+        a third-party system into Dataplex.
+
+        Returns:
+            Callable[[~.CreateMetadataJobRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "create_metadata_job" not in self._stubs:
+            self._stubs["create_metadata_job"] = self._logged_channel.unary_unary(
+                "/google.cloud.dataplex.v1.CatalogService/CreateMetadataJob",
+                request_serializer=catalog.CreateMetadataJobRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["create_metadata_job"]
+
+    @property
+    def get_metadata_job(
+        self,
+    ) -> Callable[[catalog.GetMetadataJobRequest], catalog.MetadataJob]:
+        r"""Return a callable for the get metadata job method over gRPC.
+
+        Gets a metadata job.
+
+        Returns:
+            Callable[[~.GetMetadataJobRequest],
+                    ~.MetadataJob]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_metadata_job" not in self._stubs:
+            self._stubs["get_metadata_job"] = self._logged_channel.unary_unary(
+                "/google.cloud.dataplex.v1.CatalogService/GetMetadataJob",
+                request_serializer=catalog.GetMetadataJobRequest.serialize,
+                response_deserializer=catalog.MetadataJob.deserialize,
+            )
+        return self._stubs["get_metadata_job"]
+
+    @property
+    def list_metadata_jobs(
+        self,
+    ) -> Callable[[catalog.ListMetadataJobsRequest], catalog.ListMetadataJobsResponse]:
+        r"""Return a callable for the list metadata jobs method over gRPC.
+
+        Lists metadata jobs.
+
+        Returns:
+            Callable[[~.ListMetadataJobsRequest],
+                    ~.ListMetadataJobsResponse]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "list_metadata_jobs" not in self._stubs:
+            self._stubs["list_metadata_jobs"] = self._logged_channel.unary_unary(
+                "/google.cloud.dataplex.v1.CatalogService/ListMetadataJobs",
+                request_serializer=catalog.ListMetadataJobsRequest.serialize,
+                response_deserializer=catalog.ListMetadataJobsResponse.deserialize,
+            )
+        return self._stubs["list_metadata_jobs"]
+
+    @property
+    def cancel_metadata_job(
+        self,
+    ) -> Callable[[catalog.CancelMetadataJobRequest], empty_pb2.Empty]:
+        r"""Return a callable for the cancel metadata job method over gRPC.
+
+        Cancels a metadata job.
+
+        If you cancel a metadata import job that is in progress,
+        the changes in the job might be partially applied. We
+        recommend that you reset the state of the entry groups
+        in your project by running another metadata job that
+        reverts the changes from the canceled job.
+
+        Returns:
+            Callable[[~.CancelMetadataJobRequest],
+                    ~.Empty]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "cancel_metadata_job" not in self._stubs:
+            self._stubs["cancel_metadata_job"] = self._logged_channel.unary_unary(
+                "/google.cloud.dataplex.v1.CatalogService/CancelMetadataJob",
+                request_serializer=catalog.CancelMetadataJobRequest.serialize,
+                response_deserializer=empty_pb2.Empty.FromString,
+            )
+        return self._stubs["cancel_metadata_job"]
+
     def close(self):
-        self.grpc_channel.close()
+        self._logged_channel.close()
 
     @property
     def delete_operation(
@@ -833,7 +1035,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_operation" not in self._stubs:
-            self._stubs["delete_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/DeleteOperation",
                 request_serializer=operations_pb2.DeleteOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -850,7 +1052,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "cancel_operation" not in self._stubs:
-            self._stubs["cancel_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["cancel_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/CancelOperation",
                 request_serializer=operations_pb2.CancelOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -867,7 +1069,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_operation" not in self._stubs:
-            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["get_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/GetOperation",
                 request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -886,7 +1088,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_operations" not in self._stubs:
-            self._stubs["list_operations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_operations"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/ListOperations",
                 request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
                 response_deserializer=operations_pb2.ListOperationsResponse.FromString,
@@ -905,7 +1107,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_locations" not in self._stubs:
-            self._stubs["list_locations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_locations"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/ListLocations",
                 request_serializer=locations_pb2.ListLocationsRequest.SerializeToString,
                 response_deserializer=locations_pb2.ListLocationsResponse.FromString,
@@ -922,7 +1124,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_location" not in self._stubs:
-            self._stubs["get_location"] = self.grpc_channel.unary_unary(
+            self._stubs["get_location"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/GetLocation",
                 request_serializer=locations_pb2.GetLocationRequest.SerializeToString,
                 response_deserializer=locations_pb2.Location.FromString,
