@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import json
+import logging as std_logging
+import pickle
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -24,12 +27,89 @@ from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
+from google.protobuf.json_format import MessageToJson
+import google.protobuf.message
 import grpc  # type: ignore
+import proto  # type: ignore
 
 from google.cloud.dataplex_v1.types import datascans
 
 from .base import DEFAULT_CLIENT_INFO, DataScanServiceTransport
 
+try:
+    from google.api_core import client_logging  # type: ignore
+
+    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
+    CLIENT_LOGGING_SUPPORTED = False
+
+_LOGGER = std_logging.getLogger(__name__)
+
+
+class _LoggingClientInterceptor(grpc.UnaryUnaryClientInterceptor):  # pragma: NO COVER
+    def intercept_unary_unary(self, continuation, client_call_details, request):
+        logging_enabled = CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+            std_logging.DEBUG
+        )
+        if logging_enabled:  # pragma: NO COVER
+            request_metadata = client_call_details.metadata
+            if isinstance(request, proto.Message):
+                request_payload = type(request).to_json(request)
+            elif isinstance(request, google.protobuf.message.Message):
+                request_payload = MessageToJson(request)
+            else:
+                request_payload = f"{type(request).__name__}: {pickle.dumps(request)}"
+
+            request_metadata = {
+                key: value.decode("utf-8") if isinstance(value, bytes) else value
+                for key, value in request_metadata
+            }
+            grpc_request = {
+                "payload": request_payload,
+                "requestMethod": "grpc",
+                "metadata": dict(request_metadata),
+            }
+            _LOGGER.debug(
+                f"Sending request for {client_call_details.method}",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.DataScanService",
+                    "rpcName": str(client_call_details.method),
+                    "request": grpc_request,
+                    "metadata": grpc_request["metadata"],
+                },
+            )
+        response = continuation(client_call_details, request)
+        if logging_enabled:  # pragma: NO COVER
+            response_metadata = response.trailing_metadata()
+            # Convert gRPC metadata `<class 'grpc.aio._metadata.Metadata'>` to list of tuples
+            metadata = (
+                dict([(k, str(v)) for k, v in response_metadata])
+                if response_metadata
+                else None
+            )
+            result = response.result()
+            if isinstance(result, proto.Message):
+                response_payload = type(result).to_json(result)
+            elif isinstance(result, google.protobuf.message.Message):
+                response_payload = MessageToJson(result)
+            else:
+                response_payload = f"{type(result).__name__}: {pickle.dumps(result)}"
+            grpc_response = {
+                "payload": response_payload,
+                "metadata": metadata,
+                "status": "OK",
+            }
+            _LOGGER.debug(
+                f"Received response for {client_call_details.method}.",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.DataScanService",
+                    "rpcName": client_call_details.method,
+                    "response": grpc_response,
+                    "metadata": grpc_response["metadata"],
+                },
+            )
+        return response
+
 
 class DataScanServiceGrpcTransport(DataScanServiceTransport):
     """gRPC backend transport for DataScanService.
@@ -187,7 +267,12 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
                 ],
             )
 
-        # Wrap messages. This must be done after self._grpc_channel exists
+        self._interceptor = _LoggingClientInterceptor()
+        self._logged_channel = grpc.intercept_channel(
+            self._grpc_channel, self._interceptor
+        )
+
+        # Wrap messages. This must be done after self._logged_channel exists
         self._prep_wrapped_messages(client_info)
 
     @classmethod
@@ -251,7 +336,9 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         """
         # Quick check: Only create a new client if we do not already have one.
         if self._operations_client is None:
-            self._operations_client = operations_v1.OperationsClient(self.grpc_channel)
+            self._operations_client = operations_v1.OperationsClient(
+                self._logged_channel
+            )
 
         # Return the client from cache.
         return self._operations_client
@@ -275,7 +362,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_data_scan" not in self._stubs:
-            self._stubs["create_data_scan"] = self.grpc_channel.unary_unary(
+            self._stubs["create_data_scan"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/CreateDataScan",
                 request_serializer=datascans.CreateDataScanRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -301,7 +388,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_data_scan" not in self._stubs:
-            self._stubs["update_data_scan"] = self.grpc_channel.unary_unary(
+            self._stubs["update_data_scan"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/UpdateDataScan",
                 request_serializer=datascans.UpdateDataScanRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -327,7 +414,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_data_scan" not in self._stubs:
-            self._stubs["delete_data_scan"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_data_scan"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/DeleteDataScan",
                 request_serializer=datascans.DeleteDataScanRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -353,7 +440,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_data_scan" not in self._stubs:
-            self._stubs["get_data_scan"] = self.grpc_channel.unary_unary(
+            self._stubs["get_data_scan"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/GetDataScan",
                 request_serializer=datascans.GetDataScanRequest.serialize,
                 response_deserializer=datascans.DataScan.deserialize,
@@ -379,7 +466,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_data_scans" not in self._stubs:
-            self._stubs["list_data_scans"] = self.grpc_channel.unary_unary(
+            self._stubs["list_data_scans"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/ListDataScans",
                 request_serializer=datascans.ListDataScansRequest.serialize,
                 response_deserializer=datascans.ListDataScansResponse.deserialize,
@@ -405,7 +492,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "run_data_scan" not in self._stubs:
-            self._stubs["run_data_scan"] = self.grpc_channel.unary_unary(
+            self._stubs["run_data_scan"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/RunDataScan",
                 request_serializer=datascans.RunDataScanRequest.serialize,
                 response_deserializer=datascans.RunDataScanResponse.deserialize,
@@ -431,7 +518,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_data_scan_job" not in self._stubs:
-            self._stubs["get_data_scan_job"] = self.grpc_channel.unary_unary(
+            self._stubs["get_data_scan_job"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/GetDataScanJob",
                 request_serializer=datascans.GetDataScanJobRequest.serialize,
                 response_deserializer=datascans.DataScanJob.deserialize,
@@ -459,7 +546,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_data_scan_jobs" not in self._stubs:
-            self._stubs["list_data_scan_jobs"] = self.grpc_channel.unary_unary(
+            self._stubs["list_data_scan_jobs"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/ListDataScanJobs",
                 request_serializer=datascans.ListDataScanJobsRequest.serialize,
                 response_deserializer=datascans.ListDataScanJobsResponse.deserialize,
@@ -492,7 +579,9 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "generate_data_quality_rules" not in self._stubs:
-            self._stubs["generate_data_quality_rules"] = self.grpc_channel.unary_unary(
+            self._stubs[
+                "generate_data_quality_rules"
+            ] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/GenerateDataQualityRules",
                 request_serializer=datascans.GenerateDataQualityRulesRequest.serialize,
                 response_deserializer=datascans.GenerateDataQualityRulesResponse.deserialize,
@@ -500,7 +589,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         return self._stubs["generate_data_quality_rules"]
 
     def close(self):
-        self.grpc_channel.close()
+        self._logged_channel.close()
 
     @property
     def delete_operation(
@@ -512,7 +601,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_operation" not in self._stubs:
-            self._stubs["delete_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/DeleteOperation",
                 request_serializer=operations_pb2.DeleteOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -529,7 +618,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "cancel_operation" not in self._stubs:
-            self._stubs["cancel_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["cancel_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/CancelOperation",
                 request_serializer=operations_pb2.CancelOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -546,7 +635,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_operation" not in self._stubs:
-            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["get_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/GetOperation",
                 request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -565,7 +654,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_operations" not in self._stubs:
-            self._stubs["list_operations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_operations"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/ListOperations",
                 request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
                 response_deserializer=operations_pb2.ListOperationsResponse.FromString,
@@ -584,7 +673,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_locations" not in self._stubs:
-            self._stubs["list_locations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_locations"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/ListLocations",
                 request_serializer=locations_pb2.ListLocationsRequest.SerializeToString,
                 response_deserializer=locations_pb2.ListLocationsResponse.FromString,
@@ -601,7 +690,7 @@ class DataScanServiceGrpcTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_location" not in self._stubs:
-            self._stubs["get_location"] = self.grpc_channel.unary_unary(
+            self._stubs["get_location"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/GetLocation",
                 request_serializer=locations_pb2.GetLocationRequest.SerializeToString,
                 response_deserializer=locations_pb2.Location.FromString,
