@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,9 @@
 # limitations under the License.
 #
 import inspect
+import json
+import logging as std_logging
+import pickle
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -26,14 +29,93 @@ from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
+from google.protobuf.json_format import MessageToJson
+import google.protobuf.message
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
+import proto  # type: ignore
 
 from google.cloud.dataplex_v1.types import datascans
 
 from .base import DEFAULT_CLIENT_INFO, DataScanServiceTransport
 from .grpc import DataScanServiceGrpcTransport
 
+try:
+    from google.api_core import client_logging  # type: ignore
+
+    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
+    CLIENT_LOGGING_SUPPORTED = False
+
+_LOGGER = std_logging.getLogger(__name__)
+
+
+class _LoggingClientAIOInterceptor(
+    grpc.aio.UnaryUnaryClientInterceptor
+):  # pragma: NO COVER
+    async def intercept_unary_unary(self, continuation, client_call_details, request):
+        logging_enabled = CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+            std_logging.DEBUG
+        )
+        if logging_enabled:  # pragma: NO COVER
+            request_metadata = client_call_details.metadata
+            if isinstance(request, proto.Message):
+                request_payload = type(request).to_json(request)
+            elif isinstance(request, google.protobuf.message.Message):
+                request_payload = MessageToJson(request)
+            else:
+                request_payload = f"{type(request).__name__}: {pickle.dumps(request)}"
+
+            request_metadata = {
+                key: value.decode("utf-8") if isinstance(value, bytes) else value
+                for key, value in request_metadata
+            }
+            grpc_request = {
+                "payload": request_payload,
+                "requestMethod": "grpc",
+                "metadata": dict(request_metadata),
+            }
+            _LOGGER.debug(
+                f"Sending request for {client_call_details.method}",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.DataScanService",
+                    "rpcName": str(client_call_details.method),
+                    "request": grpc_request,
+                    "metadata": grpc_request["metadata"],
+                },
+            )
+        response = await continuation(client_call_details, request)
+        if logging_enabled:  # pragma: NO COVER
+            response_metadata = await response.trailing_metadata()
+            # Convert gRPC metadata `<class 'grpc.aio._metadata.Metadata'>` to list of tuples
+            metadata = (
+                dict([(k, str(v)) for k, v in response_metadata])
+                if response_metadata
+                else None
+            )
+            result = await response
+            if isinstance(result, proto.Message):
+                response_payload = type(result).to_json(result)
+            elif isinstance(result, google.protobuf.message.Message):
+                response_payload = MessageToJson(result)
+            else:
+                response_payload = f"{type(result).__name__}: {pickle.dumps(result)}"
+            grpc_response = {
+                "payload": response_payload,
+                "metadata": metadata,
+                "status": "OK",
+            }
+            _LOGGER.debug(
+                f"Received response to rpc {client_call_details.method}.",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.DataScanService",
+                    "rpcName": str(client_call_details.method),
+                    "response": grpc_response,
+                    "metadata": grpc_response["metadata"],
+                },
+            )
+        return response
+
 
 class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
     """gRPC AsyncIO backend transport for DataScanService.
@@ -234,10 +316,13 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
                 ],
             )
 
-        # Wrap messages. This must be done after self._grpc_channel exists
+        self._interceptor = _LoggingClientAIOInterceptor()
+        self._grpc_channel._unary_unary_interceptors.append(self._interceptor)
+        self._logged_channel = self._grpc_channel
         self._wrap_with_kind = (
             "kind" in inspect.signature(gapic_v1.method_async.wrap_method).parameters
         )
+        # Wrap messages. This must be done after self._logged_channel exists
         self._prep_wrapped_messages(client_info)
 
     @property
@@ -260,7 +345,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # Quick check: Only create a new client if we do not already have one.
         if self._operations_client is None:
             self._operations_client = operations_v1.OperationsAsyncClient(
-                self.grpc_channel
+                self._logged_channel
             )
 
         # Return the client from cache.
@@ -287,7 +372,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_data_scan" not in self._stubs:
-            self._stubs["create_data_scan"] = self.grpc_channel.unary_unary(
+            self._stubs["create_data_scan"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/CreateDataScan",
                 request_serializer=datascans.CreateDataScanRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -315,7 +400,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_data_scan" not in self._stubs:
-            self._stubs["update_data_scan"] = self.grpc_channel.unary_unary(
+            self._stubs["update_data_scan"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/UpdateDataScan",
                 request_serializer=datascans.UpdateDataScanRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -343,7 +428,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_data_scan" not in self._stubs:
-            self._stubs["delete_data_scan"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_data_scan"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/DeleteDataScan",
                 request_serializer=datascans.DeleteDataScanRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -369,7 +454,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_data_scan" not in self._stubs:
-            self._stubs["get_data_scan"] = self.grpc_channel.unary_unary(
+            self._stubs["get_data_scan"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/GetDataScan",
                 request_serializer=datascans.GetDataScanRequest.serialize,
                 response_deserializer=datascans.DataScan.deserialize,
@@ -397,7 +482,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_data_scans" not in self._stubs:
-            self._stubs["list_data_scans"] = self.grpc_channel.unary_unary(
+            self._stubs["list_data_scans"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/ListDataScans",
                 request_serializer=datascans.ListDataScansRequest.serialize,
                 response_deserializer=datascans.ListDataScansResponse.deserialize,
@@ -425,7 +510,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "run_data_scan" not in self._stubs:
-            self._stubs["run_data_scan"] = self.grpc_channel.unary_unary(
+            self._stubs["run_data_scan"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/RunDataScan",
                 request_serializer=datascans.RunDataScanRequest.serialize,
                 response_deserializer=datascans.RunDataScanResponse.deserialize,
@@ -451,7 +536,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_data_scan_job" not in self._stubs:
-            self._stubs["get_data_scan_job"] = self.grpc_channel.unary_unary(
+            self._stubs["get_data_scan_job"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/GetDataScanJob",
                 request_serializer=datascans.GetDataScanJobRequest.serialize,
                 response_deserializer=datascans.DataScanJob.deserialize,
@@ -480,7 +565,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_data_scan_jobs" not in self._stubs:
-            self._stubs["list_data_scan_jobs"] = self.grpc_channel.unary_unary(
+            self._stubs["list_data_scan_jobs"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/ListDataScanJobs",
                 request_serializer=datascans.ListDataScanJobsRequest.serialize,
                 response_deserializer=datascans.ListDataScanJobsResponse.deserialize,
@@ -513,7 +598,9 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "generate_data_quality_rules" not in self._stubs:
-            self._stubs["generate_data_quality_rules"] = self.grpc_channel.unary_unary(
+            self._stubs[
+                "generate_data_quality_rules"
+            ] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataScanService/GenerateDataQualityRules",
                 request_serializer=datascans.GenerateDataQualityRulesRequest.serialize,
                 response_deserializer=datascans.GenerateDataQualityRulesResponse.deserialize,
@@ -606,7 +693,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         return gapic_v1.method_async.wrap_method(func, *args, **kwargs)
 
     def close(self):
-        return self.grpc_channel.close()
+        return self._logged_channel.close()
 
     @property
     def kind(self) -> str:
@@ -622,7 +709,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_operation" not in self._stubs:
-            self._stubs["delete_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/DeleteOperation",
                 request_serializer=operations_pb2.DeleteOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -639,7 +726,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "cancel_operation" not in self._stubs:
-            self._stubs["cancel_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["cancel_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/CancelOperation",
                 request_serializer=operations_pb2.CancelOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -656,7 +743,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_operation" not in self._stubs:
-            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["get_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/GetOperation",
                 request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -675,7 +762,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_operations" not in self._stubs:
-            self._stubs["list_operations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_operations"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/ListOperations",
                 request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
                 response_deserializer=operations_pb2.ListOperationsResponse.FromString,
@@ -694,7 +781,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_locations" not in self._stubs:
-            self._stubs["list_locations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_locations"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/ListLocations",
                 request_serializer=locations_pb2.ListLocationsRequest.SerializeToString,
                 response_deserializer=locations_pb2.ListLocationsResponse.FromString,
@@ -711,7 +798,7 @@ class DataScanServiceGrpcAsyncIOTransport(DataScanServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_location" not in self._stubs:
-            self._stubs["get_location"] = self.grpc_channel.unary_unary(
+            self._stubs["get_location"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/GetLocation",
                 request_serializer=locations_pb2.GetLocationRequest.SerializeToString,
                 response_deserializer=locations_pb2.Location.FromString,
