@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import json
+import logging as std_logging
+import pickle
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -24,13 +27,90 @@ from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
+from google.protobuf.json_format import MessageToJson
+import google.protobuf.message
 import grpc  # type: ignore
+import proto  # type: ignore
 
 from google.cloud.dataplex_v1.types import data_taxonomy
 from google.cloud.dataplex_v1.types import data_taxonomy as gcd_data_taxonomy
 
 from .base import DEFAULT_CLIENT_INFO, DataTaxonomyServiceTransport
 
+try:
+    from google.api_core import client_logging  # type: ignore
+
+    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
+    CLIENT_LOGGING_SUPPORTED = False
+
+_LOGGER = std_logging.getLogger(__name__)
+
+
+class _LoggingClientInterceptor(grpc.UnaryUnaryClientInterceptor):  # pragma: NO COVER
+    def intercept_unary_unary(self, continuation, client_call_details, request):
+        logging_enabled = CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+            std_logging.DEBUG
+        )
+        if logging_enabled:  # pragma: NO COVER
+            request_metadata = client_call_details.metadata
+            if isinstance(request, proto.Message):
+                request_payload = type(request).to_json(request)
+            elif isinstance(request, google.protobuf.message.Message):
+                request_payload = MessageToJson(request)
+            else:
+                request_payload = f"{type(request).__name__}: {pickle.dumps(request)}"
+
+            request_metadata = {
+                key: value.decode("utf-8") if isinstance(value, bytes) else value
+                for key, value in request_metadata
+            }
+            grpc_request = {
+                "payload": request_payload,
+                "requestMethod": "grpc",
+                "metadata": dict(request_metadata),
+            }
+            _LOGGER.debug(
+                f"Sending request for {client_call_details.method}",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.DataTaxonomyService",
+                    "rpcName": str(client_call_details.method),
+                    "request": grpc_request,
+                    "metadata": grpc_request["metadata"],
+                },
+            )
+        response = continuation(client_call_details, request)
+        if logging_enabled:  # pragma: NO COVER
+            response_metadata = response.trailing_metadata()
+            # Convert gRPC metadata `<class 'grpc.aio._metadata.Metadata'>` to list of tuples
+            metadata = (
+                dict([(k, str(v)) for k, v in response_metadata])
+                if response_metadata
+                else None
+            )
+            result = response.result()
+            if isinstance(result, proto.Message):
+                response_payload = type(result).to_json(result)
+            elif isinstance(result, google.protobuf.message.Message):
+                response_payload = MessageToJson(result)
+            else:
+                response_payload = f"{type(result).__name__}: {pickle.dumps(result)}"
+            grpc_response = {
+                "payload": response_payload,
+                "metadata": metadata,
+                "status": "OK",
+            }
+            _LOGGER.debug(
+                f"Received response for {client_call_details.method}.",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.DataTaxonomyService",
+                    "rpcName": client_call_details.method,
+                    "response": grpc_response,
+                    "metadata": grpc_response["metadata"],
+                },
+            )
+        return response
+
 
 class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
     """gRPC backend transport for DataTaxonomyService.
@@ -187,7 +267,12 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
                 ],
             )
 
-        # Wrap messages. This must be done after self._grpc_channel exists
+        self._interceptor = _LoggingClientInterceptor()
+        self._logged_channel = grpc.intercept_channel(
+            self._grpc_channel, self._interceptor
+        )
+
+        # Wrap messages. This must be done after self._logged_channel exists
         self._prep_wrapped_messages(client_info)
 
     @classmethod
@@ -251,7 +336,9 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         """
         # Quick check: Only create a new client if we do not already have one.
         if self._operations_client is None:
-            self._operations_client = operations_v1.OperationsClient(self.grpc_channel)
+            self._operations_client = operations_v1.OperationsClient(
+                self._logged_channel
+            )
 
         # Return the client from cache.
         return self._operations_client
@@ -277,7 +364,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_data_taxonomy" not in self._stubs:
-            self._stubs["create_data_taxonomy"] = self.grpc_channel.unary_unary(
+            self._stubs["create_data_taxonomy"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/CreateDataTaxonomy",
                 request_serializer=gcd_data_taxonomy.CreateDataTaxonomyRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -305,7 +392,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_data_taxonomy" not in self._stubs:
-            self._stubs["update_data_taxonomy"] = self.grpc_channel.unary_unary(
+            self._stubs["update_data_taxonomy"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/UpdateDataTaxonomy",
                 request_serializer=gcd_data_taxonomy.UpdateDataTaxonomyRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -333,7 +420,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_data_taxonomy" not in self._stubs:
-            self._stubs["delete_data_taxonomy"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_data_taxonomy"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/DeleteDataTaxonomy",
                 request_serializer=data_taxonomy.DeleteDataTaxonomyRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -363,7 +450,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_data_taxonomies" not in self._stubs:
-            self._stubs["list_data_taxonomies"] = self.grpc_channel.unary_unary(
+            self._stubs["list_data_taxonomies"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/ListDataTaxonomies",
                 request_serializer=data_taxonomy.ListDataTaxonomiesRequest.serialize,
                 response_deserializer=data_taxonomy.ListDataTaxonomiesResponse.deserialize,
@@ -389,7 +476,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_data_taxonomy" not in self._stubs:
-            self._stubs["get_data_taxonomy"] = self.grpc_channel.unary_unary(
+            self._stubs["get_data_taxonomy"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/GetDataTaxonomy",
                 request_serializer=data_taxonomy.GetDataTaxonomyRequest.serialize,
                 response_deserializer=data_taxonomy.DataTaxonomy.deserialize,
@@ -419,7 +506,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         if "create_data_attribute_binding" not in self._stubs:
             self._stubs[
                 "create_data_attribute_binding"
-            ] = self.grpc_channel.unary_unary(
+            ] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/CreateDataAttributeBinding",
                 request_serializer=data_taxonomy.CreateDataAttributeBindingRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -449,7 +536,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         if "update_data_attribute_binding" not in self._stubs:
             self._stubs[
                 "update_data_attribute_binding"
-            ] = self.grpc_channel.unary_unary(
+            ] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/UpdateDataAttributeBinding",
                 request_serializer=data_taxonomy.UpdateDataAttributeBindingRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -481,7 +568,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         if "delete_data_attribute_binding" not in self._stubs:
             self._stubs[
                 "delete_data_attribute_binding"
-            ] = self.grpc_channel.unary_unary(
+            ] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/DeleteDataAttributeBinding",
                 request_serializer=data_taxonomy.DeleteDataAttributeBindingRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -511,7 +598,9 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_data_attribute_bindings" not in self._stubs:
-            self._stubs["list_data_attribute_bindings"] = self.grpc_channel.unary_unary(
+            self._stubs[
+                "list_data_attribute_bindings"
+            ] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/ListDataAttributeBindings",
                 request_serializer=data_taxonomy.ListDataAttributeBindingsRequest.serialize,
                 response_deserializer=data_taxonomy.ListDataAttributeBindingsResponse.deserialize,
@@ -540,7 +629,9 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_data_attribute_binding" not in self._stubs:
-            self._stubs["get_data_attribute_binding"] = self.grpc_channel.unary_unary(
+            self._stubs[
+                "get_data_attribute_binding"
+            ] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/GetDataAttributeBinding",
                 request_serializer=data_taxonomy.GetDataAttributeBindingRequest.serialize,
                 response_deserializer=data_taxonomy.DataAttributeBinding.deserialize,
@@ -566,7 +657,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_data_attribute" not in self._stubs:
-            self._stubs["create_data_attribute"] = self.grpc_channel.unary_unary(
+            self._stubs["create_data_attribute"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/CreateDataAttribute",
                 request_serializer=data_taxonomy.CreateDataAttributeRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -592,7 +683,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_data_attribute" not in self._stubs:
-            self._stubs["update_data_attribute"] = self.grpc_channel.unary_unary(
+            self._stubs["update_data_attribute"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/UpdateDataAttribute",
                 request_serializer=data_taxonomy.UpdateDataAttributeRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -618,7 +709,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_data_attribute" not in self._stubs:
-            self._stubs["delete_data_attribute"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_data_attribute"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/DeleteDataAttribute",
                 request_serializer=data_taxonomy.DeleteDataAttributeRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -647,7 +738,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_data_attributes" not in self._stubs:
-            self._stubs["list_data_attributes"] = self.grpc_channel.unary_unary(
+            self._stubs["list_data_attributes"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/ListDataAttributes",
                 request_serializer=data_taxonomy.ListDataAttributesRequest.serialize,
                 response_deserializer=data_taxonomy.ListDataAttributesResponse.deserialize,
@@ -673,7 +764,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_data_attribute" not in self._stubs:
-            self._stubs["get_data_attribute"] = self.grpc_channel.unary_unary(
+            self._stubs["get_data_attribute"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataTaxonomyService/GetDataAttribute",
                 request_serializer=data_taxonomy.GetDataAttributeRequest.serialize,
                 response_deserializer=data_taxonomy.DataAttribute.deserialize,
@@ -681,7 +772,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         return self._stubs["get_data_attribute"]
 
     def close(self):
-        self.grpc_channel.close()
+        self._logged_channel.close()
 
     @property
     def delete_operation(
@@ -693,7 +784,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_operation" not in self._stubs:
-            self._stubs["delete_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/DeleteOperation",
                 request_serializer=operations_pb2.DeleteOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -710,7 +801,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "cancel_operation" not in self._stubs:
-            self._stubs["cancel_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["cancel_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/CancelOperation",
                 request_serializer=operations_pb2.CancelOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -727,7 +818,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_operation" not in self._stubs:
-            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["get_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/GetOperation",
                 request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -746,7 +837,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_operations" not in self._stubs:
-            self._stubs["list_operations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_operations"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/ListOperations",
                 request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
                 response_deserializer=operations_pb2.ListOperationsResponse.FromString,
@@ -765,7 +856,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_locations" not in self._stubs:
-            self._stubs["list_locations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_locations"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/ListLocations",
                 request_serializer=locations_pb2.ListLocationsRequest.SerializeToString,
                 response_deserializer=locations_pb2.ListLocationsResponse.FromString,
@@ -782,7 +873,7 @@ class DataTaxonomyServiceGrpcTransport(DataTaxonomyServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_location" not in self._stubs:
-            self._stubs["get_location"] = self.grpc_channel.unary_unary(
+            self._stubs["get_location"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/GetLocation",
                 request_serializer=locations_pb2.GetLocationRequest.SerializeToString,
                 response_deserializer=locations_pb2.Location.FromString,
