@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,9 @@
 # limitations under the License.
 #
 import inspect
+import json
+import logging as std_logging
+import pickle
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -27,14 +30,93 @@ from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf.json_format import MessageToJson
+import google.protobuf.message
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
+import proto  # type: ignore
 
 from google.cloud.dataplex_v1.types import analyze, resources, service, tasks
 
 from .base import DEFAULT_CLIENT_INFO, DataplexServiceTransport
 from .grpc import DataplexServiceGrpcTransport
 
+try:
+    from google.api_core import client_logging  # type: ignore
+
+    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
+    CLIENT_LOGGING_SUPPORTED = False
+
+_LOGGER = std_logging.getLogger(__name__)
+
+
+class _LoggingClientAIOInterceptor(
+    grpc.aio.UnaryUnaryClientInterceptor
+):  # pragma: NO COVER
+    async def intercept_unary_unary(self, continuation, client_call_details, request):
+        logging_enabled = CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+            std_logging.DEBUG
+        )
+        if logging_enabled:  # pragma: NO COVER
+            request_metadata = client_call_details.metadata
+            if isinstance(request, proto.Message):
+                request_payload = type(request).to_json(request)
+            elif isinstance(request, google.protobuf.message.Message):
+                request_payload = MessageToJson(request)
+            else:
+                request_payload = f"{type(request).__name__}: {pickle.dumps(request)}"
+
+            request_metadata = {
+                key: value.decode("utf-8") if isinstance(value, bytes) else value
+                for key, value in request_metadata
+            }
+            grpc_request = {
+                "payload": request_payload,
+                "requestMethod": "grpc",
+                "metadata": dict(request_metadata),
+            }
+            _LOGGER.debug(
+                f"Sending request for {client_call_details.method}",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.DataplexService",
+                    "rpcName": str(client_call_details.method),
+                    "request": grpc_request,
+                    "metadata": grpc_request["metadata"],
+                },
+            )
+        response = await continuation(client_call_details, request)
+        if logging_enabled:  # pragma: NO COVER
+            response_metadata = await response.trailing_metadata()
+            # Convert gRPC metadata `<class 'grpc.aio._metadata.Metadata'>` to list of tuples
+            metadata = (
+                dict([(k, str(v)) for k, v in response_metadata])
+                if response_metadata
+                else None
+            )
+            result = await response
+            if isinstance(result, proto.Message):
+                response_payload = type(result).to_json(result)
+            elif isinstance(result, google.protobuf.message.Message):
+                response_payload = MessageToJson(result)
+            else:
+                response_payload = f"{type(result).__name__}: {pickle.dumps(result)}"
+            grpc_response = {
+                "payload": response_payload,
+                "metadata": metadata,
+                "status": "OK",
+            }
+            _LOGGER.debug(
+                f"Received response to rpc {client_call_details.method}.",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.DataplexService",
+                    "rpcName": str(client_call_details.method),
+                    "response": grpc_response,
+                    "metadata": grpc_response["metadata"],
+                },
+            )
+        return response
+
 
 class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
     """gRPC AsyncIO backend transport for DataplexService.
@@ -237,10 +319,13 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
                 ],
             )
 
-        # Wrap messages. This must be done after self._grpc_channel exists
+        self._interceptor = _LoggingClientAIOInterceptor()
+        self._grpc_channel._unary_unary_interceptors.append(self._interceptor)
+        self._logged_channel = self._grpc_channel
         self._wrap_with_kind = (
             "kind" in inspect.signature(gapic_v1.method_async.wrap_method).parameters
         )
+        # Wrap messages. This must be done after self._logged_channel exists
         self._prep_wrapped_messages(client_info)
 
     @property
@@ -263,7 +348,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # Quick check: Only create a new client if we do not already have one.
         if self._operations_client is None:
             self._operations_client = operations_v1.OperationsAsyncClient(
-                self.grpc_channel
+                self._logged_channel
             )
 
         # Return the client from cache.
@@ -288,7 +373,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_lake" not in self._stubs:
-            self._stubs["create_lake"] = self.grpc_channel.unary_unary(
+            self._stubs["create_lake"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/CreateLake",
                 request_serializer=service.CreateLakeRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -314,7 +399,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_lake" not in self._stubs:
-            self._stubs["update_lake"] = self.grpc_channel.unary_unary(
+            self._stubs["update_lake"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/UpdateLake",
                 request_serializer=service.UpdateLakeRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -341,7 +426,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_lake" not in self._stubs:
-            self._stubs["delete_lake"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_lake"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/DeleteLake",
                 request_serializer=service.DeleteLakeRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -367,7 +452,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_lakes" not in self._stubs:
-            self._stubs["list_lakes"] = self.grpc_channel.unary_unary(
+            self._stubs["list_lakes"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/ListLakes",
                 request_serializer=service.ListLakesRequest.serialize,
                 response_deserializer=service.ListLakesResponse.deserialize,
@@ -391,7 +476,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_lake" not in self._stubs:
-            self._stubs["get_lake"] = self.grpc_channel.unary_unary(
+            self._stubs["get_lake"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/GetLake",
                 request_serializer=service.GetLakeRequest.serialize,
                 response_deserializer=resources.Lake.deserialize,
@@ -419,7 +504,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_lake_actions" not in self._stubs:
-            self._stubs["list_lake_actions"] = self.grpc_channel.unary_unary(
+            self._stubs["list_lake_actions"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/ListLakeActions",
                 request_serializer=service.ListLakeActionsRequest.serialize,
                 response_deserializer=service.ListActionsResponse.deserialize,
@@ -445,7 +530,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_zone" not in self._stubs:
-            self._stubs["create_zone"] = self.grpc_channel.unary_unary(
+            self._stubs["create_zone"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/CreateZone",
                 request_serializer=service.CreateZoneRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -471,7 +556,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_zone" not in self._stubs:
-            self._stubs["update_zone"] = self.grpc_channel.unary_unary(
+            self._stubs["update_zone"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/UpdateZone",
                 request_serializer=service.UpdateZoneRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -498,7 +583,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_zone" not in self._stubs:
-            self._stubs["delete_zone"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_zone"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/DeleteZone",
                 request_serializer=service.DeleteZoneRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -524,7 +609,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_zones" not in self._stubs:
-            self._stubs["list_zones"] = self.grpc_channel.unary_unary(
+            self._stubs["list_zones"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/ListZones",
                 request_serializer=service.ListZonesRequest.serialize,
                 response_deserializer=service.ListZonesResponse.deserialize,
@@ -548,7 +633,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_zone" not in self._stubs:
-            self._stubs["get_zone"] = self.grpc_channel.unary_unary(
+            self._stubs["get_zone"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/GetZone",
                 request_serializer=service.GetZoneRequest.serialize,
                 response_deserializer=resources.Zone.deserialize,
@@ -576,7 +661,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_zone_actions" not in self._stubs:
-            self._stubs["list_zone_actions"] = self.grpc_channel.unary_unary(
+            self._stubs["list_zone_actions"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/ListZoneActions",
                 request_serializer=service.ListZoneActionsRequest.serialize,
                 response_deserializer=service.ListActionsResponse.deserialize,
@@ -602,7 +687,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_asset" not in self._stubs:
-            self._stubs["create_asset"] = self.grpc_channel.unary_unary(
+            self._stubs["create_asset"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/CreateAsset",
                 request_serializer=service.CreateAssetRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -628,7 +713,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_asset" not in self._stubs:
-            self._stubs["update_asset"] = self.grpc_channel.unary_unary(
+            self._stubs["update_asset"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/UpdateAsset",
                 request_serializer=service.UpdateAssetRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -656,7 +741,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_asset" not in self._stubs:
-            self._stubs["delete_asset"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_asset"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/DeleteAsset",
                 request_serializer=service.DeleteAssetRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -682,7 +767,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_assets" not in self._stubs:
-            self._stubs["list_assets"] = self.grpc_channel.unary_unary(
+            self._stubs["list_assets"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/ListAssets",
                 request_serializer=service.ListAssetsRequest.serialize,
                 response_deserializer=service.ListAssetsResponse.deserialize,
@@ -708,7 +793,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_asset" not in self._stubs:
-            self._stubs["get_asset"] = self.grpc_channel.unary_unary(
+            self._stubs["get_asset"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/GetAsset",
                 request_serializer=service.GetAssetRequest.serialize,
                 response_deserializer=resources.Asset.deserialize,
@@ -736,7 +821,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_asset_actions" not in self._stubs:
-            self._stubs["list_asset_actions"] = self.grpc_channel.unary_unary(
+            self._stubs["list_asset_actions"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/ListAssetActions",
                 request_serializer=service.ListAssetActionsRequest.serialize,
                 response_deserializer=service.ListActionsResponse.deserialize,
@@ -762,7 +847,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_task" not in self._stubs:
-            self._stubs["create_task"] = self.grpc_channel.unary_unary(
+            self._stubs["create_task"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/CreateTask",
                 request_serializer=service.CreateTaskRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -788,7 +873,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_task" not in self._stubs:
-            self._stubs["update_task"] = self.grpc_channel.unary_unary(
+            self._stubs["update_task"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/UpdateTask",
                 request_serializer=service.UpdateTaskRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -814,7 +899,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_task" not in self._stubs:
-            self._stubs["delete_task"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_task"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/DeleteTask",
                 request_serializer=service.DeleteTaskRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -840,7 +925,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_tasks" not in self._stubs:
-            self._stubs["list_tasks"] = self.grpc_channel.unary_unary(
+            self._stubs["list_tasks"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/ListTasks",
                 request_serializer=service.ListTasksRequest.serialize,
                 response_deserializer=service.ListTasksResponse.deserialize,
@@ -864,7 +949,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_task" not in self._stubs:
-            self._stubs["get_task"] = self.grpc_channel.unary_unary(
+            self._stubs["get_task"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/GetTask",
                 request_serializer=service.GetTaskRequest.serialize,
                 response_deserializer=tasks.Task.deserialize,
@@ -890,7 +975,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_jobs" not in self._stubs:
-            self._stubs["list_jobs"] = self.grpc_channel.unary_unary(
+            self._stubs["list_jobs"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/ListJobs",
                 request_serializer=service.ListJobsRequest.serialize,
                 response_deserializer=service.ListJobsResponse.deserialize,
@@ -916,7 +1001,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "run_task" not in self._stubs:
-            self._stubs["run_task"] = self.grpc_channel.unary_unary(
+            self._stubs["run_task"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/RunTask",
                 request_serializer=service.RunTaskRequest.serialize,
                 response_deserializer=service.RunTaskResponse.deserialize,
@@ -940,7 +1025,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_job" not in self._stubs:
-            self._stubs["get_job"] = self.grpc_channel.unary_unary(
+            self._stubs["get_job"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/GetJob",
                 request_serializer=service.GetJobRequest.serialize,
                 response_deserializer=tasks.Job.deserialize,
@@ -966,7 +1051,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "cancel_job" not in self._stubs:
-            self._stubs["cancel_job"] = self.grpc_channel.unary_unary(
+            self._stubs["cancel_job"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/CancelJob",
                 request_serializer=service.CancelJobRequest.serialize,
                 response_deserializer=empty_pb2.Empty.FromString,
@@ -994,7 +1079,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_environment" not in self._stubs:
-            self._stubs["create_environment"] = self.grpc_channel.unary_unary(
+            self._stubs["create_environment"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/CreateEnvironment",
                 request_serializer=service.CreateEnvironmentRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -1022,7 +1107,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_environment" not in self._stubs:
-            self._stubs["update_environment"] = self.grpc_channel.unary_unary(
+            self._stubs["update_environment"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/UpdateEnvironment",
                 request_serializer=service.UpdateEnvironmentRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -1052,7 +1137,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_environment" not in self._stubs:
-            self._stubs["delete_environment"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_environment"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/DeleteEnvironment",
                 request_serializer=service.DeleteEnvironmentRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -1080,7 +1165,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_environments" not in self._stubs:
-            self._stubs["list_environments"] = self.grpc_channel.unary_unary(
+            self._stubs["list_environments"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/ListEnvironments",
                 request_serializer=service.ListEnvironmentsRequest.serialize,
                 response_deserializer=service.ListEnvironmentsResponse.deserialize,
@@ -1106,7 +1191,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_environment" not in self._stubs:
-            self._stubs["get_environment"] = self.grpc_channel.unary_unary(
+            self._stubs["get_environment"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/GetEnvironment",
                 request_serializer=service.GetEnvironmentRequest.serialize,
                 response_deserializer=analyze.Environment.deserialize,
@@ -1134,7 +1219,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_sessions" not in self._stubs:
-            self._stubs["list_sessions"] = self.grpc_channel.unary_unary(
+            self._stubs["list_sessions"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.DataplexService/ListSessions",
                 request_serializer=service.ListSessionsRequest.serialize,
                 response_deserializer=service.ListSessionsResponse.deserialize,
@@ -1482,7 +1567,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         return gapic_v1.method_async.wrap_method(func, *args, **kwargs)
 
     def close(self):
-        return self.grpc_channel.close()
+        return self._logged_channel.close()
 
     @property
     def kind(self) -> str:
@@ -1498,7 +1583,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_operation" not in self._stubs:
-            self._stubs["delete_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/DeleteOperation",
                 request_serializer=operations_pb2.DeleteOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -1515,7 +1600,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "cancel_operation" not in self._stubs:
-            self._stubs["cancel_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["cancel_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/CancelOperation",
                 request_serializer=operations_pb2.CancelOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -1532,7 +1617,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_operation" not in self._stubs:
-            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["get_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/GetOperation",
                 request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -1551,7 +1636,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_operations" not in self._stubs:
-            self._stubs["list_operations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_operations"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/ListOperations",
                 request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
                 response_deserializer=operations_pb2.ListOperationsResponse.FromString,
@@ -1570,7 +1655,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_locations" not in self._stubs:
-            self._stubs["list_locations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_locations"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/ListLocations",
                 request_serializer=locations_pb2.ListLocationsRequest.SerializeToString,
                 response_deserializer=locations_pb2.ListLocationsResponse.FromString,
@@ -1587,7 +1672,7 @@ class DataplexServiceGrpcAsyncIOTransport(DataplexServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_location" not in self._stubs:
-            self._stubs["get_location"] = self.grpc_channel.unary_unary(
+            self._stubs["get_location"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/GetLocation",
                 request_serializer=locations_pb2.GetLocationRequest.SerializeToString,
                 response_deserializer=locations_pb2.Location.FromString,
