@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import json
+import logging as std_logging
+import pickle
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -25,12 +28,89 @@ from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf.json_format import MessageToJson
+import google.protobuf.message
 import grpc  # type: ignore
+import proto  # type: ignore
 
 from google.cloud.dataplex_v1.types import metadata_
 
 from .base import DEFAULT_CLIENT_INFO, MetadataServiceTransport
 
+try:
+    from google.api_core import client_logging  # type: ignore
+
+    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
+    CLIENT_LOGGING_SUPPORTED = False
+
+_LOGGER = std_logging.getLogger(__name__)
+
+
+class _LoggingClientInterceptor(grpc.UnaryUnaryClientInterceptor):  # pragma: NO COVER
+    def intercept_unary_unary(self, continuation, client_call_details, request):
+        logging_enabled = CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+            std_logging.DEBUG
+        )
+        if logging_enabled:  # pragma: NO COVER
+            request_metadata = client_call_details.metadata
+            if isinstance(request, proto.Message):
+                request_payload = type(request).to_json(request)
+            elif isinstance(request, google.protobuf.message.Message):
+                request_payload = MessageToJson(request)
+            else:
+                request_payload = f"{type(request).__name__}: {pickle.dumps(request)}"
+
+            request_metadata = {
+                key: value.decode("utf-8") if isinstance(value, bytes) else value
+                for key, value in request_metadata
+            }
+            grpc_request = {
+                "payload": request_payload,
+                "requestMethod": "grpc",
+                "metadata": dict(request_metadata),
+            }
+            _LOGGER.debug(
+                f"Sending request for {client_call_details.method}",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.MetadataService",
+                    "rpcName": str(client_call_details.method),
+                    "request": grpc_request,
+                    "metadata": grpc_request["metadata"],
+                },
+            )
+        response = continuation(client_call_details, request)
+        if logging_enabled:  # pragma: NO COVER
+            response_metadata = response.trailing_metadata()
+            # Convert gRPC metadata `<class 'grpc.aio._metadata.Metadata'>` to list of tuples
+            metadata = (
+                dict([(k, str(v)) for k, v in response_metadata])
+                if response_metadata
+                else None
+            )
+            result = response.result()
+            if isinstance(result, proto.Message):
+                response_payload = type(result).to_json(result)
+            elif isinstance(result, google.protobuf.message.Message):
+                response_payload = MessageToJson(result)
+            else:
+                response_payload = f"{type(result).__name__}: {pickle.dumps(result)}"
+            grpc_response = {
+                "payload": response_payload,
+                "metadata": metadata,
+                "status": "OK",
+            }
+            _LOGGER.debug(
+                f"Received response for {client_call_details.method}.",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.MetadataService",
+                    "rpcName": client_call_details.method,
+                    "response": grpc_response,
+                    "metadata": grpc_response["metadata"],
+                },
+            )
+        return response
+
 
 class MetadataServiceGrpcTransport(MetadataServiceTransport):
     """gRPC backend transport for MetadataService.
@@ -185,7 +265,12 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
                 ],
             )
 
-        # Wrap messages. This must be done after self._grpc_channel exists
+        self._interceptor = _LoggingClientInterceptor()
+        self._logged_channel = grpc.intercept_channel(
+            self._grpc_channel, self._interceptor
+        )
+
+        # Wrap messages. This must be done after self._logged_channel exists
         self._prep_wrapped_messages(client_info)
 
     @classmethod
@@ -259,7 +344,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_entity" not in self._stubs:
-            self._stubs["create_entity"] = self.grpc_channel.unary_unary(
+            self._stubs["create_entity"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/CreateEntity",
                 request_serializer=metadata_.CreateEntityRequest.serialize,
                 response_deserializer=metadata_.Entity.deserialize,
@@ -286,7 +371,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_entity" not in self._stubs:
-            self._stubs["update_entity"] = self.grpc_channel.unary_unary(
+            self._stubs["update_entity"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/UpdateEntity",
                 request_serializer=metadata_.UpdateEntityRequest.serialize,
                 response_deserializer=metadata_.Entity.deserialize,
@@ -312,7 +397,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_entity" not in self._stubs:
-            self._stubs["delete_entity"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_entity"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/DeleteEntity",
                 request_serializer=metadata_.DeleteEntityRequest.serialize,
                 response_deserializer=empty_pb2.Empty.FromString,
@@ -336,7 +421,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_entity" not in self._stubs:
-            self._stubs["get_entity"] = self.grpc_channel.unary_unary(
+            self._stubs["get_entity"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/GetEntity",
                 request_serializer=metadata_.GetEntityRequest.serialize,
                 response_deserializer=metadata_.Entity.deserialize,
@@ -362,7 +447,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_entities" not in self._stubs:
-            self._stubs["list_entities"] = self.grpc_channel.unary_unary(
+            self._stubs["list_entities"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/ListEntities",
                 request_serializer=metadata_.ListEntitiesRequest.serialize,
                 response_deserializer=metadata_.ListEntitiesResponse.deserialize,
@@ -388,7 +473,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_partition" not in self._stubs:
-            self._stubs["create_partition"] = self.grpc_channel.unary_unary(
+            self._stubs["create_partition"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/CreatePartition",
                 request_serializer=metadata_.CreatePartitionRequest.serialize,
                 response_deserializer=metadata_.Partition.deserialize,
@@ -414,7 +499,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_partition" not in self._stubs:
-            self._stubs["delete_partition"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_partition"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/DeletePartition",
                 request_serializer=metadata_.DeletePartitionRequest.serialize,
                 response_deserializer=empty_pb2.Empty.FromString,
@@ -440,7 +525,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_partition" not in self._stubs:
-            self._stubs["get_partition"] = self.grpc_channel.unary_unary(
+            self._stubs["get_partition"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/GetPartition",
                 request_serializer=metadata_.GetPartitionRequest.serialize,
                 response_deserializer=metadata_.Partition.deserialize,
@@ -466,7 +551,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_partitions" not in self._stubs:
-            self._stubs["list_partitions"] = self.grpc_channel.unary_unary(
+            self._stubs["list_partitions"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/ListPartitions",
                 request_serializer=metadata_.ListPartitionsRequest.serialize,
                 response_deserializer=metadata_.ListPartitionsResponse.deserialize,
@@ -474,7 +559,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         return self._stubs["list_partitions"]
 
     def close(self):
-        self.grpc_channel.close()
+        self._logged_channel.close()
 
     @property
     def delete_operation(
@@ -486,7 +571,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_operation" not in self._stubs:
-            self._stubs["delete_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/DeleteOperation",
                 request_serializer=operations_pb2.DeleteOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -503,7 +588,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "cancel_operation" not in self._stubs:
-            self._stubs["cancel_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["cancel_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/CancelOperation",
                 request_serializer=operations_pb2.CancelOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -520,7 +605,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_operation" not in self._stubs:
-            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["get_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/GetOperation",
                 request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -539,7 +624,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_operations" not in self._stubs:
-            self._stubs["list_operations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_operations"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/ListOperations",
                 request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
                 response_deserializer=operations_pb2.ListOperationsResponse.FromString,
@@ -558,7 +643,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_locations" not in self._stubs:
-            self._stubs["list_locations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_locations"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/ListLocations",
                 request_serializer=locations_pb2.ListLocationsRequest.SerializeToString,
                 response_deserializer=locations_pb2.ListLocationsResponse.FromString,
@@ -575,7 +660,7 @@ class MetadataServiceGrpcTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_location" not in self._stubs:
-            self._stubs["get_location"] = self.grpc_channel.unary_unary(
+            self._stubs["get_location"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/GetLocation",
                 request_serializer=locations_pb2.GetLocationRequest.SerializeToString,
                 response_deserializer=locations_pb2.Location.FromString,
