@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,9 @@
 # limitations under the License.
 #
 import inspect
+import json
+import logging as std_logging
+import pickle
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -27,14 +30,93 @@ from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf.json_format import MessageToJson
+import google.protobuf.message
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
+import proto  # type: ignore
 
 from google.cloud.dataplex_v1.types import metadata_
 
 from .base import DEFAULT_CLIENT_INFO, MetadataServiceTransport
 from .grpc import MetadataServiceGrpcTransport
 
+try:
+    from google.api_core import client_logging  # type: ignore
+
+    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
+    CLIENT_LOGGING_SUPPORTED = False
+
+_LOGGER = std_logging.getLogger(__name__)
+
+
+class _LoggingClientAIOInterceptor(
+    grpc.aio.UnaryUnaryClientInterceptor
+):  # pragma: NO COVER
+    async def intercept_unary_unary(self, continuation, client_call_details, request):
+        logging_enabled = CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+            std_logging.DEBUG
+        )
+        if logging_enabled:  # pragma: NO COVER
+            request_metadata = client_call_details.metadata
+            if isinstance(request, proto.Message):
+                request_payload = type(request).to_json(request)
+            elif isinstance(request, google.protobuf.message.Message):
+                request_payload = MessageToJson(request)
+            else:
+                request_payload = f"{type(request).__name__}: {pickle.dumps(request)}"
+
+            request_metadata = {
+                key: value.decode("utf-8") if isinstance(value, bytes) else value
+                for key, value in request_metadata
+            }
+            grpc_request = {
+                "payload": request_payload,
+                "requestMethod": "grpc",
+                "metadata": dict(request_metadata),
+            }
+            _LOGGER.debug(
+                f"Sending request for {client_call_details.method}",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.MetadataService",
+                    "rpcName": str(client_call_details.method),
+                    "request": grpc_request,
+                    "metadata": grpc_request["metadata"],
+                },
+            )
+        response = await continuation(client_call_details, request)
+        if logging_enabled:  # pragma: NO COVER
+            response_metadata = await response.trailing_metadata()
+            # Convert gRPC metadata `<class 'grpc.aio._metadata.Metadata'>` to list of tuples
+            metadata = (
+                dict([(k, str(v)) for k, v in response_metadata])
+                if response_metadata
+                else None
+            )
+            result = await response
+            if isinstance(result, proto.Message):
+                response_payload = type(result).to_json(result)
+            elif isinstance(result, google.protobuf.message.Message):
+                response_payload = MessageToJson(result)
+            else:
+                response_payload = f"{type(result).__name__}: {pickle.dumps(result)}"
+            grpc_response = {
+                "payload": response_payload,
+                "metadata": metadata,
+                "status": "OK",
+            }
+            _LOGGER.debug(
+                f"Received response to rpc {client_call_details.method}.",
+                extra={
+                    "serviceName": "google.cloud.dataplex.v1.MetadataService",
+                    "rpcName": str(client_call_details.method),
+                    "response": grpc_response,
+                    "metadata": grpc_response["metadata"],
+                },
+            )
+        return response
+
 
 class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
     """gRPC AsyncIO backend transport for MetadataService.
@@ -232,10 +314,13 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
                 ],
             )
 
-        # Wrap messages. This must be done after self._grpc_channel exists
+        self._interceptor = _LoggingClientAIOInterceptor()
+        self._grpc_channel._unary_unary_interceptors.append(self._interceptor)
+        self._logged_channel = self._grpc_channel
         self._wrap_with_kind = (
             "kind" in inspect.signature(gapic_v1.method_async.wrap_method).parameters
         )
+        # Wrap messages. This must be done after self._logged_channel exists
         self._prep_wrapped_messages(client_info)
 
     @property
@@ -267,7 +352,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_entity" not in self._stubs:
-            self._stubs["create_entity"] = self.grpc_channel.unary_unary(
+            self._stubs["create_entity"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/CreateEntity",
                 request_serializer=metadata_.CreateEntityRequest.serialize,
                 response_deserializer=metadata_.Entity.deserialize,
@@ -294,7 +379,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_entity" not in self._stubs:
-            self._stubs["update_entity"] = self.grpc_channel.unary_unary(
+            self._stubs["update_entity"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/UpdateEntity",
                 request_serializer=metadata_.UpdateEntityRequest.serialize,
                 response_deserializer=metadata_.Entity.deserialize,
@@ -320,7 +405,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_entity" not in self._stubs:
-            self._stubs["delete_entity"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_entity"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/DeleteEntity",
                 request_serializer=metadata_.DeleteEntityRequest.serialize,
                 response_deserializer=empty_pb2.Empty.FromString,
@@ -346,7 +431,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_entity" not in self._stubs:
-            self._stubs["get_entity"] = self.grpc_channel.unary_unary(
+            self._stubs["get_entity"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/GetEntity",
                 request_serializer=metadata_.GetEntityRequest.serialize,
                 response_deserializer=metadata_.Entity.deserialize,
@@ -374,7 +459,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_entities" not in self._stubs:
-            self._stubs["list_entities"] = self.grpc_channel.unary_unary(
+            self._stubs["list_entities"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/ListEntities",
                 request_serializer=metadata_.ListEntitiesRequest.serialize,
                 response_deserializer=metadata_.ListEntitiesResponse.deserialize,
@@ -400,7 +485,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_partition" not in self._stubs:
-            self._stubs["create_partition"] = self.grpc_channel.unary_unary(
+            self._stubs["create_partition"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/CreatePartition",
                 request_serializer=metadata_.CreatePartitionRequest.serialize,
                 response_deserializer=metadata_.Partition.deserialize,
@@ -426,7 +511,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_partition" not in self._stubs:
-            self._stubs["delete_partition"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_partition"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/DeletePartition",
                 request_serializer=metadata_.DeletePartitionRequest.serialize,
                 response_deserializer=empty_pb2.Empty.FromString,
@@ -452,7 +537,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_partition" not in self._stubs:
-            self._stubs["get_partition"] = self.grpc_channel.unary_unary(
+            self._stubs["get_partition"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/GetPartition",
                 request_serializer=metadata_.GetPartitionRequest.serialize,
                 response_deserializer=metadata_.Partition.deserialize,
@@ -480,7 +565,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_partitions" not in self._stubs:
-            self._stubs["list_partitions"] = self.grpc_channel.unary_unary(
+            self._stubs["list_partitions"] = self._logged_channel.unary_unary(
                 "/google.cloud.dataplex.v1.MetadataService/ListPartitions",
                 request_serializer=metadata_.ListPartitionsRequest.serialize,
                 response_deserializer=metadata_.ListPartitionsResponse.deserialize,
@@ -609,7 +694,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         return gapic_v1.method_async.wrap_method(func, *args, **kwargs)
 
     def close(self):
-        return self.grpc_channel.close()
+        return self._logged_channel.close()
 
     @property
     def kind(self) -> str:
@@ -625,7 +710,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_operation" not in self._stubs:
-            self._stubs["delete_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/DeleteOperation",
                 request_serializer=operations_pb2.DeleteOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -642,7 +727,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "cancel_operation" not in self._stubs:
-            self._stubs["cancel_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["cancel_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/CancelOperation",
                 request_serializer=operations_pb2.CancelOperationRequest.SerializeToString,
                 response_deserializer=None,
@@ -659,7 +744,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_operation" not in self._stubs:
-            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
+            self._stubs["get_operation"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/GetOperation",
                 request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -678,7 +763,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_operations" not in self._stubs:
-            self._stubs["list_operations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_operations"] = self._logged_channel.unary_unary(
                 "/google.longrunning.Operations/ListOperations",
                 request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
                 response_deserializer=operations_pb2.ListOperationsResponse.FromString,
@@ -697,7 +782,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_locations" not in self._stubs:
-            self._stubs["list_locations"] = self.grpc_channel.unary_unary(
+            self._stubs["list_locations"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/ListLocations",
                 request_serializer=locations_pb2.ListLocationsRequest.SerializeToString,
                 response_deserializer=locations_pb2.ListLocationsResponse.FromString,
@@ -714,7 +799,7 @@ class MetadataServiceGrpcAsyncIOTransport(MetadataServiceTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_location" not in self._stubs:
-            self._stubs["get_location"] = self.grpc_channel.unary_unary(
+            self._stubs["get_location"] = self._logged_channel.unary_unary(
                 "/google.cloud.location.Locations/GetLocation",
                 request_serializer=locations_pb2.GetLocationRequest.SerializeToString,
                 response_deserializer=locations_pb2.Location.FromString,
