@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,6 +22,7 @@ from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.dataplex_v1.types import (
+    data_discovery,
     data_profile,
     data_quality,
     processing,
@@ -52,19 +53,22 @@ __protobuf__ = proto.module(
 
 
 class DataScanType(proto.Enum):
-    r"""The type of DataScan.
+    r"""The type of data scan.
 
     Values:
         DATA_SCAN_TYPE_UNSPECIFIED (0):
-            The DataScan type is unspecified.
+            The data scan type is unspecified.
         DATA_QUALITY (1):
-            Data Quality scan.
+            Data quality scan.
         DATA_PROFILE (2):
-            Data Profile scan.
+            Data profile scan.
+        DATA_DISCOVERY (3):
+            Data discovery scan.
     """
     DATA_SCAN_TYPE_UNSPECIFIED = 0
     DATA_QUALITY = 1
     DATA_PROFILE = 2
+    DATA_DISCOVERY = 3
 
 
 class CreateDataScanRequest(proto.Message):
@@ -119,7 +123,7 @@ class UpdateDataScanRequest(proto.Message):
 
             Only fields specified in ``update_mask`` are updated.
         update_mask (google.protobuf.field_mask_pb2.FieldMask):
-            Required. Mask of fields to update.
+            Optional. Mask of fields to update.
         validate_only (bool):
             Optional. Only validate the request, but do not perform
             mutations. The default is ``false``.
@@ -150,12 +154,21 @@ class DeleteDataScanRequest(proto.Message):
             ``projects/{project}/locations/{location_id}/dataScans/{data_scan_id}``
             where ``project`` refers to a *project_id* or
             *project_number* and ``location_id`` refers to a GCP region.
+        force (bool):
+            Optional. If set to true, any child resources
+            of this data scan will also be deleted.
+            (Otherwise, the request will only work if the
+            data scan has no child resources.)
     """
 
     name: str = proto.Field(
         proto.STRING,
         number=1,
     )
+    force: bool = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
 
 
 class GetDataScanRequest(proto.Message):
@@ -487,11 +500,19 @@ class DataScan(proto.Message):
 
     For example:
 
-    -  Data Quality: generates queries based on the rules and runs
-       against the data to get data quality check results.
-    -  Data Profile: analyzes the data in table(s) and generates
-       insights about the structure, content and relationships (such as
-       null percent, cardinality, min/max/mean, etc).
+    -  Data quality: generates queries based on the rules and runs
+       against the data to get data quality check results. For more
+       information, see `Auto data quality
+       overview <https://cloud.google.com/dataplex/docs/auto-data-quality-overview>`__.
+    -  Data profile: analyzes the data in tables and generates insights
+       about the structure, content and relationships (such as null
+       percent, cardinality, min/max/mean, etc). For more information,
+       see `About data
+       profiling <https://cloud.google.com/dataplex/docs/data-profiling-overview>`__.
+    -  Data discovery: scans data in Cloud Storage buckets to extract
+       and then catalog metadata. For more information, see `Discover
+       and catalog Cloud Storage
+       data <https://cloud.google.com/bigquery/docs/automatic-discovery>`__.
 
     This message has `oneof`_ fields (mutually exclusive fields).
     For each oneof, at most one member field can be set at the same time.
@@ -502,8 +523,8 @@ class DataScan(proto.Message):
 
     Attributes:
         name (str):
-            Output only. The relative resource name of the scan, of the
-            form:
+            Output only. Identifier. The relative resource name of the
+            scan, of the form:
             ``projects/{project}/locations/{location_id}/dataScans/{datascan_id}``,
             where ``project`` refers to a *project_id* or
             *project_number* and ``location_id`` refers to a GCP region.
@@ -543,20 +564,29 @@ class DataScan(proto.Message):
         type_ (google.cloud.dataplex_v1.types.DataScanType):
             Output only. The type of DataScan.
         data_quality_spec (google.cloud.dataplex_v1.types.DataQualitySpec):
-            DataQualityScan related setting.
+            Settings for a data quality scan.
 
             This field is a member of `oneof`_ ``spec``.
         data_profile_spec (google.cloud.dataplex_v1.types.DataProfileSpec):
-            DataProfileScan related setting.
+            Settings for a data profile scan.
+
+            This field is a member of `oneof`_ ``spec``.
+        data_discovery_spec (google.cloud.dataplex_v1.types.DataDiscoverySpec):
+            Settings for a data discovery scan.
 
             This field is a member of `oneof`_ ``spec``.
         data_quality_result (google.cloud.dataplex_v1.types.DataQualityResult):
-            Output only. The result of the data quality
+            Output only. The result of a data quality
             scan.
 
             This field is a member of `oneof`_ ``result``.
         data_profile_result (google.cloud.dataplex_v1.types.DataProfileResult):
-            Output only. The result of the data profile
+            Output only. The result of a data profile
+            scan.
+
+            This field is a member of `oneof`_ ``result``.
+        data_discovery_result (google.cloud.dataplex_v1.types.DataDiscoveryResult):
+            Output only. The result of a data discovery
             scan.
 
             This field is a member of `oneof`_ ``result``.
@@ -602,9 +632,11 @@ class DataScan(proto.Message):
 
         Attributes:
             latest_job_start_time (google.protobuf.timestamp_pb2.Timestamp):
-                The time when the latest DataScanJob started.
+                Optional. The time when the latest
+                DataScanJob started.
             latest_job_end_time (google.protobuf.timestamp_pb2.Timestamp):
-                The time when the latest DataScanJob ended.
+                Optional. The time when the latest
+                DataScanJob ended.
             latest_job_create_time (google.protobuf.timestamp_pb2.Timestamp):
                 Optional. The time when the DataScanJob
                 execution was created.
@@ -694,6 +726,12 @@ class DataScan(proto.Message):
         oneof="spec",
         message=data_profile.DataProfileSpec,
     )
+    data_discovery_spec: data_discovery.DataDiscoverySpec = proto.Field(
+        proto.MESSAGE,
+        number=102,
+        oneof="spec",
+        message=data_discovery.DataDiscoverySpec,
+    )
     data_quality_result: data_quality.DataQualityResult = proto.Field(
         proto.MESSAGE,
         number=200,
@@ -706,6 +744,12 @@ class DataScan(proto.Message):
         oneof="result",
         message=data_profile.DataProfileResult,
     )
+    data_discovery_result: data_discovery.DataDiscoveryResult = proto.Field(
+        proto.MESSAGE,
+        number=202,
+        oneof="result",
+        message=data_discovery.DataDiscoveryResult,
+    )
 
 
 class DataScanJob(proto.Message):
@@ -720,14 +764,17 @@ class DataScanJob(proto.Message):
 
     Attributes:
         name (str):
-            Output only. The relative resource name of the DataScanJob,
-            of the form:
+            Output only. Identifier. The relative resource name of the
+            DataScanJob, of the form:
             ``projects/{project}/locations/{location_id}/dataScans/{datascan_id}/jobs/{job_id}``,
             where ``project`` refers to a *project_id* or
             *project_number* and ``location_id`` refers to a GCP region.
         uid (str):
             Output only. System generated globally unique
             ID for the DataScanJob.
+        create_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. The time when the DataScanJob
+            was created.
         start_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The time when the DataScanJob
             was started.
@@ -743,20 +790,32 @@ class DataScanJob(proto.Message):
         type_ (google.cloud.dataplex_v1.types.DataScanType):
             Output only. The type of the parent DataScan.
         data_quality_spec (google.cloud.dataplex_v1.types.DataQualitySpec):
-            Output only. DataQualityScan related setting.
+            Output only. Settings for a data quality
+            scan.
 
             This field is a member of `oneof`_ ``spec``.
         data_profile_spec (google.cloud.dataplex_v1.types.DataProfileSpec):
-            Output only. DataProfileScan related setting.
+            Output only. Settings for a data profile
+            scan.
+
+            This field is a member of `oneof`_ ``spec``.
+        data_discovery_spec (google.cloud.dataplex_v1.types.DataDiscoverySpec):
+            Output only. Settings for a data discovery
+            scan.
 
             This field is a member of `oneof`_ ``spec``.
         data_quality_result (google.cloud.dataplex_v1.types.DataQualityResult):
-            Output only. The result of the data quality
+            Output only. The result of a data quality
             scan.
 
             This field is a member of `oneof`_ ``result``.
         data_profile_result (google.cloud.dataplex_v1.types.DataProfileResult):
-            Output only. The result of the data profile
+            Output only. The result of a data profile
+            scan.
+
+            This field is a member of `oneof`_ ``result``.
+        data_discovery_result (google.cloud.dataplex_v1.types.DataDiscoveryResult):
+            Output only. The result of a data discovery
             scan.
 
             This field is a member of `oneof`_ ``result``.
@@ -799,6 +858,11 @@ class DataScanJob(proto.Message):
         proto.STRING,
         number=2,
     )
+    create_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=timestamp_pb2.Timestamp,
+    )
     start_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
@@ -835,6 +899,12 @@ class DataScanJob(proto.Message):
         oneof="spec",
         message=data_profile.DataProfileSpec,
     )
+    data_discovery_spec: data_discovery.DataDiscoverySpec = proto.Field(
+        proto.MESSAGE,
+        number=102,
+        oneof="spec",
+        message=data_discovery.DataDiscoverySpec,
+    )
     data_quality_result: data_quality.DataQualityResult = proto.Field(
         proto.MESSAGE,
         number=200,
@@ -847,6 +917,12 @@ class DataScanJob(proto.Message):
         oneof="result",
         message=data_profile.DataProfileResult,
     )
+    data_discovery_result: data_discovery.DataDiscoveryResult = proto.Field(
+        proto.MESSAGE,
+        number=202,
+        oneof="result",
+        message=data_discovery.DataDiscoveryResult,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
