@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -30,6 +30,8 @@ __protobuf__ = proto.module(
         "GovernanceEvent",
         "DataScanEvent",
         "DataQualityScanRuleResult",
+        "BusinessGlossaryEvent",
+        "EntryLinkEvent",
     },
 )
 
@@ -55,6 +57,9 @@ class DiscoveryEvent(proto.Message):
             The id of the associated asset.
         data_location (str):
             The data location associated with the event.
+        datascan_id (str):
+            The id of the associated datascan for
+            standalone discovery.
         type_ (google.cloud.dataplex_v1.types.DiscoveryEvent.EventType):
             The type of the event being logged.
         config (google.cloud.dataplex_v1.types.DiscoveryEvent.ConfigDetails):
@@ -76,6 +81,11 @@ class DiscoveryEvent(proto.Message):
             Details about the action associated with the
             event.
 
+            This field is a member of `oneof`_ ``details``.
+        table (google.cloud.dataplex_v1.types.DiscoveryEvent.TableDetails):
+            Details about the BigQuery table publishing
+            associated with the event.
+
             This field is a member of `oneof`_ ``details``.
     """
 
@@ -106,6 +116,16 @@ class DiscoveryEvent(proto.Message):
             PARTITION_DELETED (7):
                 An event representing a partition being
                 deleted.
+            TABLE_PUBLISHED (10):
+                An event representing a table being
+                published.
+            TABLE_UPDATED (11):
+                An event representing a table being updated.
+            TABLE_IGNORED (12):
+                An event representing a table being skipped
+                in publishing.
+            TABLE_DELETED (13):
+                An event representing a table being deleted.
         """
         EVENT_TYPE_UNSPECIFIED = 0
         CONFIG = 1
@@ -115,6 +135,10 @@ class DiscoveryEvent(proto.Message):
         PARTITION_CREATED = 5
         PARTITION_UPDATED = 6
         PARTITION_DELETED = 7
+        TABLE_PUBLISHED = 10
+        TABLE_UPDATED = 11
+        TABLE_IGNORED = 12
+        TABLE_DELETED = 13
 
     class EntityType(proto.Enum):
         r"""The type of the entity.
@@ -131,6 +155,24 @@ class DiscoveryEvent(proto.Message):
         TABLE = 1
         FILESET = 2
 
+    class TableType(proto.Enum):
+        r"""The type of the published table.
+
+        Values:
+            TABLE_TYPE_UNSPECIFIED (0):
+                An unspecified table type.
+            EXTERNAL_TABLE (1):
+                External table type.
+            BIGLAKE_TABLE (2):
+                BigLake table type.
+            OBJECT_TABLE (3):
+                Object table type for unstructured data.
+        """
+        TABLE_TYPE_UNSPECIFIED = 0
+        EXTERNAL_TABLE = 1
+        BIGLAKE_TABLE = 2
+        OBJECT_TABLE = 3
+
     class ConfigDetails(proto.Message):
         r"""Details about configuration events.
 
@@ -170,6 +212,27 @@ class DiscoveryEvent(proto.Message):
             enum="DiscoveryEvent.EntityType",
         )
 
+    class TableDetails(proto.Message):
+        r"""Details about the published table.
+
+        Attributes:
+            table (str):
+                The fully-qualified resource name of the
+                table resource.
+            type_ (google.cloud.dataplex_v1.types.DiscoveryEvent.TableType):
+                The type of the table resource.
+        """
+
+        table: str = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        type_: "DiscoveryEvent.TableType" = proto.Field(
+            proto.ENUM,
+            number=2,
+            enum="DiscoveryEvent.TableType",
+        )
+
     class PartitionDetails(proto.Message):
         r"""Details about the partition.
 
@@ -213,12 +276,19 @@ class DiscoveryEvent(proto.Message):
             type_ (str):
                 The type of action.
                 Eg. IncompatibleDataSchema, InvalidDataFormat
+            issue (str):
+                The human readable issue associated with the
+                action.
         """
 
         type_: str = proto.Field(
             proto.STRING,
             number=1,
         )
+        issue: str = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
     message: str = proto.Field(
         proto.STRING,
@@ -240,6 +310,10 @@ class DiscoveryEvent(proto.Message):
         proto.STRING,
         number=5,
     )
+    datascan_id: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
     type_: EventType = proto.Field(
         proto.ENUM,
         number=10,
@@ -269,6 +343,12 @@ class DiscoveryEvent(proto.Message):
         oneof="details",
         message=ActionDetails,
     )
+    table: TableDetails = proto.Field(
+        proto.MESSAGE,
+        number=24,
+        oneof="details",
+        message=TableDetails,
+    )
 
 
 class JobEvent(proto.Message):
@@ -699,7 +779,6 @@ class GovernanceEvent(proto.Message):
 class DataScanEvent(proto.Message):
     r"""These messages contain information about the execution of a
     datascan. The monitored resource is 'DataScan'
-    Next ID: 13
 
     This message has `oneof`_ fields (mutually exclusive fields).
     For each oneof, at most one member field can be set at the same time.
@@ -770,10 +849,13 @@ class DataScanEvent(proto.Message):
                 Data scan for data profile.
             DATA_QUALITY (2):
                 Data scan for data quality.
+            DATA_DISCOVERY (4):
+                Data scan for data discovery.
         """
         SCAN_TYPE_UNSPECIFIED = 0
         DATA_PROFILE = 1
         DATA_QUALITY = 2
+        DATA_DISCOVERY = 4
 
     class State(proto.Enum):
         r"""The job state of the data scan.
@@ -1276,4 +1358,109 @@ class DataQualityScanRuleResult(proto.Message):
     )
 
 
+class BusinessGlossaryEvent(proto.Message):
+    r"""Payload associated with Business Glossary related log events.
+
+    Attributes:
+        message (str):
+            The log message.
+        event_type (google.cloud.dataplex_v1.types.BusinessGlossaryEvent.EventType):
+            The type of the event.
+        resource (str):
+            Name of the resource.
+    """
+
+    class EventType(proto.Enum):
+        r"""Type of glossary log event.
+
+        Values:
+            EVENT_TYPE_UNSPECIFIED (0):
+                An unspecified event type.
+            GLOSSARY_CREATE (1):
+                Glossary create event.
+            GLOSSARY_UPDATE (2):
+                Glossary update event.
+            GLOSSARY_DELETE (3):
+                Glossary delete event.
+            GLOSSARY_CATEGORY_CREATE (4):
+                Glossary category create event.
+            GLOSSARY_CATEGORY_UPDATE (5):
+                Glossary category update event.
+            GLOSSARY_CATEGORY_DELETE (6):
+                Glossary category delete event.
+            GLOSSARY_TERM_CREATE (7):
+                Glossary term create event.
+            GLOSSARY_TERM_UPDATE (8):
+                Glossary term update event.
+            GLOSSARY_TERM_DELETE (9):
+                Glossary term delete event.
+        """
+        EVENT_TYPE_UNSPECIFIED = 0
+        GLOSSARY_CREATE = 1
+        GLOSSARY_UPDATE = 2
+        GLOSSARY_DELETE = 3
+        GLOSSARY_CATEGORY_CREATE = 4
+        GLOSSARY_CATEGORY_UPDATE = 5
+        GLOSSARY_CATEGORY_DELETE = 6
+        GLOSSARY_TERM_CREATE = 7
+        GLOSSARY_TERM_UPDATE = 8
+        GLOSSARY_TERM_DELETE = 9
+
+    message: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    event_type: EventType = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=EventType,
+    )
+    resource: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+
+
+class EntryLinkEvent(proto.Message):
+    r"""Payload associated with Entry related log events.
+
+    Attributes:
+        message (str):
+            The log message.
+        event_type (google.cloud.dataplex_v1.types.EntryLinkEvent.EventType):
+            The type of the event.
+        resource (str):
+            Name of the resource.
+    """
+
+    class EventType(proto.Enum):
+        r"""Type of entry link log event.
+
+        Values:
+            EVENT_TYPE_UNSPECIFIED (0):
+                An unspecified event type.
+            ENTRY_LINK_CREATE (1):
+                EntryLink create event.
+            ENTRY_LINK_DELETE (2):
+                EntryLink delete event.
+        """
+        EVENT_TYPE_UNSPECIFIED = 0
+        ENTRY_LINK_CREATE = 1
+        ENTRY_LINK_DELETE = 2
+
+    message: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    event_type: EventType = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=EventType,
+    )
+    resource: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
