@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -406,18 +406,14 @@ class Zone(proto.Message):
                 Optional. Cron schedule (https://en.wikipedia.org/wiki/Cron)
                 for running discovery periodically. Successive discovery
                 runs must be scheduled at least 60 minutes apart. The
-                default value is to run discovery every 60 minutes. To
-                explicitly set a timezone to the cron tab, apply a prefix in
-                the cron tab: "CRON_TZ=${IANA_TIME_ZONE}" or
+                default value is to run discovery every 60 minutes.
+
+                To explicitly set a timezone to the cron tab, apply a prefix
+                in the cron tab: "CRON_TZ=${IANA_TIME_ZONE}" or
                 TZ=${IANA_TIME_ZONE}". The ${IANA_TIME_ZONE} may only be a
                 valid string from IANA time zone database. For example,
-                \`CRON_TZ=America/New_York 1
-
-                -
-
-                   -
-
-                      -  \*\ ``, or``\ TZ=America/New_York 1 \* \* \* \*`.
+                ``CRON_TZ=America/New_York 1 * * * *``, or
+                ``TZ=America/New_York 1 * * * *``.
 
                 This field is a member of `oneof`_ ``trigger``.
         """
@@ -1056,18 +1052,14 @@ class Asset(proto.Message):
                 Optional. Cron schedule (https://en.wikipedia.org/wiki/Cron)
                 for running discovery periodically. Successive discovery
                 runs must be scheduled at least 60 minutes apart. The
-                default value is to run discovery every 60 minutes. To
-                explicitly set a timezone to the cron tab, apply a prefix in
-                the cron tab: "CRON_TZ=${IANA_TIME_ZONE}" or
+                default value is to run discovery every 60 minutes.
+
+                To explicitly set a timezone to the cron tab, apply a prefix
+                in the cron tab: "CRON_TZ=${IANA_TIME_ZONE}" or
                 TZ=${IANA_TIME_ZONE}". The ${IANA_TIME_ZONE} may only be a
                 valid string from IANA time zone database. For example,
-                \`CRON_TZ=America/New_York 1
-
-                -
-
-                   -
-
-                      -  \*\ ``, or``\ TZ=America/New_York 1 \* \* \* \*`.
+                ``CRON_TZ=America/New_York 1 * * * *``, or
+                ``TZ=America/New_York 1 * * * *``.
 
                 This field is a member of `oneof`_ ``trigger``.
         """
